log_layer

Function log_layer 

pub fn log_layer(config: LoggerConfig) -> Result<LogLayer, Error>
Creates a new LogLayer, using the parameters provided by the given LoggerConfig.

This should allow the subscriber to perform logging in an identical fashion to the functionality provided in fern_logger.

Errors

This function can fail in the following ways:

  • An io::Error was encountered when creating any log files required by the config.