pub struct FlamegraphLayer { /* private fields */ }Expand description
A tracing_subscriber::Layer for generating a flamegraph of tracked Spans.
This layer registers an interest in the following Span targets:
trace_tools::observe: Generated by implementers of theObservetrait.tokio::task: Used internally bytokioto instrument tasks, when compiling with--cfg tokio_unstableflags.Spans with the nameruntime.spawn: used internally by newer versions oftokioto instrument tasks, when compiling with--cfg tokio_unstableflags.